import {Injectable} from "@angular/core";
import {Todo} from "./todo";

const STORAGE_KEY = 'todos';

@Injectable({
  providedIn: 'root'
})
export class TodoService {
  get todos(): Todo[] {
    const todos = localStorage.getItem(STORAGE_KEY);

    return todos ? JSON.parse(todos) as Todo[] : [];
  }

  get categories(): string[] {
    return this.todos.map(todo => todo.category).filter((value, index, self) => self.indexOf(value) === index);
  }

  delete(todo: Todo): void {
    const todos = this.todos;
    const index = todos.findIndex(t => t.id === todo.id);
    todos.splice(index, 1);
    this.set(todos);
  }

  add(newTodo: { dueDate: Date; title: string; category: string }) {
    const todo = newTodo as Todo;
    todo.id = this.todos.length + 1;
    todo.completed = false;
    this.set([...this.todos, todo]);
  }

  set(todo: Todo[]): void {
    localStorage.setItem(STORAGE_KEY, JSON.stringify(todo));
  }

  toggleCompleted(todo: Todo) {
    const todos = this.todos;
    const index = todos.findIndex(t => t.id === todo.id);
    todos[index].completed = !todos[index].completed;
    this.set(todos);
  }
}
